@@ -1,13 +1,15 @@
 import assert from 'assert';
 import { lexer } from 'css-tree';
 import prepareTokens from '../lexer/prepare-tokens.js';
-import genericSyntaxes from '../lexer/generic.js';
+import { createGenericTypes } from '../lexer/generic.js';
+import * as units from '../lexer/units.js';
 import { buildMatchGraph } from '../lexer/match-graph.js';
 import { matchAsList, matchAsTree } from '../lexer/match.js';
 import * as fixture from './fixture/definition-syntax-match.js';
 
 const defaultTypes = Object.create(null);
 const defaultProperties = Object.create(null);
+const genericSyntaxes = createGenericTypes(units);
 
 for (const [name, def] of Object.entries(lexer.types)) {
     defaultTypes[name] = def.match;
