@@ -23,7 +23,7 @@ function createIteratorStateCollector(retValue) {
 
     return {
         states,
-        collect: function(...args) {
+        collect(...args) {
             states.push(getIteratorState(this, ...args));
             return retValue;
         }
