@@ -85,7 +85,7 @@ function isCommaContextEnd(token) {
         token.type === TYPE.RightParenthesis ||
         token.type === TYPE.RightSquareBracket ||
         token.type === TYPE.RightCurlyBracket ||
-        token.type === TYPE.Delim
+        (token.type === TYPE.Delim && token.value === '/')
     );
 }
 
