@@ -35,10 +35,16 @@ export default {
     'has': selectorList,
     'lang': identList,
     'matches': selectorList,
+    'is': selectorList,
+    '-moz-any': selectorList,
+    '-webkit-any': selectorList,
+    'where': selectorList,
     'not': selectorList,
     'nth-child': nth,
     'nth-last-child': nth,
     'nth-last-of-type': nth,
     'nth-of-type': nth,
-    'slotted': selector
+    'slotted': selector,
+    'host': selector,
+    'host-context': selector
 };
